@@ -33,7 +33,7 @@ pub fn get_test_tree_and_keys() -> (SGTree<usize, &'static str>, Vec<usize>) {
 
 // Pretty print tree.
 pub fn pretty_print<K: Ord + fmt::Debug, V>(sgt: &SGTree<K, V>) {
-    let sgt_lisp = sgt_to_lisp_str(&sgt);
+    let sgt_lisp = sgt_to_lisp_str(sgt);
     if sgt_lisp == "()" {
         println!("(empty tree)");
     } else {
@@ -182,7 +182,7 @@ fn logical_fuzz(iter_cnt: usize, check_invars: bool) {
             "Keys in reference BTree and NOT in SGTree: {:?}",
             diff_other
         );
-        assert!(false, "Keys do not match shadow set!");
+        panic!("Keys do not match shadow set!");
     }
 
     println!(
@@ -488,13 +488,13 @@ fn test_subtree_rebalance() {
 #[test]
 fn test_logical_fuzz_fast() {
     let sgt: SGTree<usize, &str> = SGTree::new();
-    logical_fuzz(sgt.capacity(), false);         // Stack-only
+    logical_fuzz(sgt.capacity(), false); // Stack-only
     logical_fuzz(sgt.capacity() + 2_000, false); // Stack + Heap
 }
 
 #[test]
 fn test_logical_fuzz_slow() {
     let sgt: SGTree<usize, &str> = SGTree::new();
-    logical_fuzz(sgt.capacity(), true);         // Stack-only
+    logical_fuzz(sgt.capacity(), true); // Stack-only
     logical_fuzz(sgt.capacity() + 2_000, true); // Stack + Heap
 }
